@@ -4,7 +4,7 @@ import subprocess
 import sys
 from datetime import timedelta
 from pathlib import Path
-from signal import SIGINT, SIGPIPE, signal
+from signal import SIG_IGN, SIGINT, SIGPIPE, SIGTSTP, signal
 from subprocess import CalledProcessError
 from textwrap import dedent
 from typing import List, Sequence, Tuple
@@ -303,13 +303,9 @@ def _set_handlers(instance):
         # loops with Ansible due to missing SSH public keys.
         Config.touch_instance(instance, error=True)
 
-    def int_handler(signum, frame):
-        # Ignore Control-Cs.
-        # Let them be handled by the remote shell
-        pass
-
     signal(SIGPIPE, pipe_handler)
-    signal(SIGINT, int_handler)
+    signal(SIGINT, SIG_IGN)
+    signal(SIGTSTP, SIG_IGN)
 
 
 def start_tunnel(client, instance: str, port: int):
